#! /bin/bash

# Creator:  Scott Lucas
# About:    This script can roll one die or n dice of x size
# Syntax:   roll [<n>]d<x>

#################### NOTES ####################
# Basic roll:   echo $((RANDOM % 20 + 1))     #
# Input syntax: dx, ndx                       #
# Regex:        ([0-9]*)?d([0-9]*)            #
# Pseudoex:     n?dx                          #
#################### NOTES ####################

# Let's get a few things set up first:
regex="([0-9]*)?d([0-9]*)"   # Store the regex in a variable
rolls=""    # Store a list of all rolls
input=$1    # Get user input
RANDOM=$$   # Seed RANDOM with PID

# Now let's get to work on the input and a few more variables:
[[ $input =~ $regex ]]   # Compare w/ the regex to get $n and $x
n="${BASH_REMATCH[1]}"   # CG 1: number of rolls to do
x="${BASH_REMATCH[2]}"   # CG 2: Size of dice



# Time to get down to business:
if [ -z "$n" ]; then    # If $n is empty...
    echo "Rolling one d$x..."
    
    # Roll just one die
    roll=$(($RANDOM % $x + 1))
    
    # And echo the output
    echo $roll
else    # Else, there is an $n...
    echo "Rolling $n d${x}s..."
    
    # Roll a bunch of dice...
    for (( i=1; $i <= $n; i++ )); do
        # Roll each die
        roll=$(( $RANDOM % $x + 1 ))
        
        # Add each roll to the total
        total=$(( $total + $roll ))
        
        # Add roll to the list of rolls
        rolls="${rolls}$roll\t"
        
        # For every five lines, add a newline for spacing, except for the very last line:
        if [[ $(( $i % 5 )) -eq 0 && $(( $n - $i )) -ne 0 ]]; then
            rolls="${rolls}\n"
        fi
    done
    
    # Echo all the rolls
    echo -e $rolls
    
    # And echo the grand total
    echo -e "Total:\t$total"
fi   # End if

